@@ -46,12 +46,22 @@
 #include <string.h>
 #include <unistd.h>
 #include <glib.h>
-#include <sys/stat.h>
+#ifndef G_OS_WIN32
 #include <pwd.h>
+#endif
 #include <limits.h>
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-util.h>
 
+#ifdef G_OS_WIN32
+#include <windows.h>
+#endif
+
+#if defined(__APPLE__) && defined(HAVE_NSGETENVIRON) && defined(HAVE_CRT_EXTERNS_H)
+# include <crt_externs.h>
+# define environ (*_NSGetEnviron())
+#endif
+
 /**
  * gnome_util_user_shell:
  *
@@ -62,6 +72,7 @@
 char *
 gnome_util_user_shell (void)
 {
+#ifndef G_OS_WIN32
 	struct passwd *pw;
 	int i;
 	const char *shell;
@@ -102,6 +113,20 @@ gnome_util_user_shell (void)
 
 	/* Placate compiler.  */
 	return NULL;
+#else
+	/* g_find_program_in_path() always looks also in the Windows
+	 * and System32 directories, so it should always find either cmd.exe
+	 * or command.com.
+	 */
+	char *retval = g_find_program_in_path ("cmd.exe");
+
+	if (retval == NULL)
+		retval = g_find_program_in_path ("command.com");
+
+	g_assert (retval != NULL);
+
+	return retval;
+#endif
 }
 
 /**
@@ -233,7 +258,6 @@ gnome_clearenv (void)
 #endif
 }
 
-
 /* Deprecated: */
 /**
  * gnome_is_program_in_path:
